/***************************************
	Auteur : Pierre Aubert
	Mail : pierre.aubert@lapp.in2p3.fr
	Licence : CeCILL-C
****************************************/
#include <iostream>

#include <numeric>
#include <execution>
#include <curand.h>
#include <thrust/host_vector.h>
#include <thrust/device_vector.h>

int main(void){
	size_t nbElement(100000000lu);
	thrust::host_vector<float> hValue(nbElement);
	thrust::device_vector<float> dValue = hValue;
	//Create the generator
	curandGenerator_t generator;
	curandCreateGenerator(&generator, CURAND_RNG_PSEUDO_DEFAULT);
	//Set the random seed
	curandSetPseudoRandomGeneratorSeed(generator, 42);
	//Generate a normal distribution (generator, data, size, mean, std)
	curandGenerateNormal(generator, (float*)dValue.data().get(), nbElement, 2.0f, 1.0f);
	//Destroy the generator
	curandDestroyGenerator(generator);
	float res = std::reduce(std::execution::par_unseq,  dValue.begin(), dValue.end());
	std::cout << "mean = " << (res/((float)nbElement)) << std::endl;
	return 0;
}

